summaryrefslogtreecommitdiffstats
path: root/src/kvilib/core/kvi_string.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit9ca32ef31a2566af48c06f258722738df92366af (patch)
treec847db3bf1bb88b7863fed0cc60eef6bf641306a /src/kvilib/core/kvi_string.cpp
parent72aaee9802d447ee21340b011856b9b355a58f1a (diff)
downloadkvirc-9ca32ef31a2566af48c06f258722738df92366af.tar.gz
kvirc-9ca32ef31a2566af48c06f258722738df92366af.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kvirc@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/kvilib/core/kvi_string.cpp')
-rw-r--r--src/kvilib/core/kvi_string.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/kvilib/core/kvi_string.cpp b/src/kvilib/core/kvi_string.cpp
index 3eb7fa67..525ad714 100644
--- a/src/kvilib/core/kvi_string.cpp
+++ b/src/kvilib/core/kvi_string.cpp
@@ -402,8 +402,8 @@ bool kvi_matchWildExpr(register const char *m1,register const char *m2)
// s1
// m1
- // tqmask1 : *xor
- // tqmask2 : xorand*xor
+ // mask1 : *xor
+ // mask2 : xorand*xor
// m2
// s2
@@ -423,7 +423,7 @@ bool kvi_matchWildExpr(register const char *m1,register const char *m2)
const char * savePos2 = m2;
while(*m1)
{
//loop managed by m1 (initially first tqmask)
if(*m1=='*')
{
//Found a wildcard in m1
@@ -450,8 +450,8 @@ bool kvi_matchWildExpr(register const char *m1,register const char *m2)
if(*m2 == '*')
{
//A wlidcard in the second string
- //Invert the game : tqmask1 <-> tqmask2
- //tqmask2 now leads the game...
+ //Invert the game : mask1 <-> mask2
+ //mask2 now leads the game...
savePos1 = m1; //aux
m1 = m2; //...swap
m2 = savePos1; //...swap
@@ -497,7 +497,7 @@ bool kvi_matchWildExprCS(register const char *m1,register const char *m2)
if(!(m1 && m2 && (*m1)))return false;
const char * savePos1 = 0;
const char * savePos2 = m2;
- while(*m1){ //loop managed by m1 (initially first tqmask)
+ while(*m1){ //loop managed by m1 (initially first mask)
if(*m1=='*'){
//Found a wildcard in m1
savePos1 = ++m1; //move to the next char and save the position...this is our jolly
@@ -520,8 +520,8 @@ bool kvi_matchWildExprCS(register const char *m1,register const char *m2)
} else {
if(*m2 == '*'){
//A wlidcard in the second string
- //Invert the game : tqmask1 <-> tqmask2
- //tqmask2 now leads the game...
+ //Invert the game : mask1 <-> mask2
+ //mask2 now leads the game...
savePos1 = m1; //aux
m1 = m2; //...swap
m2 = savePos1; //...swap
@@ -554,7 +554,7 @@ bool kvi_matchWildExprWithTerminator(register const char *m1,register const char
const char * savePos2 = m2;
while(NOT_AT_END(m1))
{
//loop managed by m1 (initially first tqmask)
if(*m1=='*')
{
//Found a wildcard in m1
@@ -588,8 +588,8 @@ bool kvi_matchWildExprWithTerminator(register const char *m1,register const char
if(*m2 == '*')
{
//A wlidcard in the second string
- //Invert the game : tqmask1 <-> tqmask2
- //tqmask2 now leads the game...
+ //Invert the game : mask1 <-> mask2
+ //mask2 now leads the game...
bSwapped = !bSwapped;
savePos1 = m1; //aux
m1 = m2; //...swap
@@ -423,7 +423,7 @@ bool kvi_matchWildExpr(register const char *m1,register const char *m2)
while(*m1)
{
- //loop managed by m1 (initially first tqmask)
+ //loop managed by m1 (initially first mask)
if(*m1=='*')
{
@@ -554,7 +554,7 @@ bool kvi_matchWildExprWithTerminator(register const char *m1,register const char
while(NOT_AT_END(m1))
{
- //loop managed by m1 (initially first tqmask)
+ //loop managed by m1 (initially first mask)
if(*m1=='*')
{